==> openmw_0.49.0.orig.tar.gz: openmw-openmw-0.49.0/AUTHORS.md <==
Contributors
============

The OpenMW project was started in 2008 by Nicolay Korslund.
In the course of years many people have contributed to the project.

If you feel your name is missing from this list, please add it to `AUTHORS.md`.


Programmers
-----------

    Bret Curtis (psi29a) - Project leader 2019-present
    Marc Zinnschlag (Zini) - Project leader 2010-2018
    Nicolay Korslund - Project leader 2008-2010
    scrawl - Top contributor

    AbduSharif
    Adam Hogan (aurix)
    Aesylwinn
    aegis
    AHSauge
    Aleksandar Jovanov
    Alex Haddad (rainChu)
    Alex McKibben
    alexanderkjall
    Alexander Nadeau (wareya)
    Alexander Olofsson (Ananace)
    Alex Rice
    Alex S (docwest)
    Alexey Yaryshev (skeevert)
    Allofich
    Andreas Stöckel
    Andrei Kortunov (akortunov)
    Andrew Appuhamy (andrew-app)
    Andrzej Głuszak (agluszak)
    AnyOldName3
    Ardekantur
    Armin Preiml
    Artem Kotsynyak (greye)
    Artem Nykolenko (anikm21)
    artemutin
    Arthur Moore (EmperorArthur)
    Assumeru
    athile
    Aussiemon
    Austin Salgat (Salgat)
    Ben Shealy (bentsherman)
    Berulacks
    Bo Svensson
    Britt Mathis (galdor557)
    Capostrophic
    Carl Maxwell
    cc9cii
    Cédric Mocquillon
    Chris Boyce (slothlife)
    Chris Robinson (KittyCat)
    Chris Vigil
    Cody Glassman (Wazabear)
    Coleman Smith (olcoal)
    Cory F. Cohen (cfcohen)
    Cris Mihalache (Mirceam)
    crussell187
    Sam Hellawell (cykoder)
    Dan Vukelich (sanchezman)
    darkf
    Dave Corley (S3ctor)
    David Cernat (davidcernat)
    Declan Millar (declan-millar)
    devnexen
    Dieho
    Dmitry Shkurskiy (endorph)
    Douglas Diniz (Dgdiniz)
    Douglas Mencken (dougmencken)
    dreamer-dead
    David Teviotdale (dteviot)
    Diggory Hardy
    Dmitry Marakasov (AMDmi3)
    Duncan Frost (duncans_pumpkin)
    Edmondo Tommasina (edmondo)
    Eduard Cot (trombonecot)
    Eli2
    Emanuel Guével (potatoesmaster)
    Epoch
    Eris Caffee (eris)
    eroen
    escondida
    Evgeniy Mineev (sandstranger)
    Federico Guerra (FedeWar)
    Fil Krynicki (filkry)
    Finbar Crago (finbar-crago)
    Florent Teppe (Tetramir)
    Florian Weber (Florianjw)
    Frédéric Chardon (fr3dz10)
    Gaëtan Dezeiraud (Brouilles)
    Gašper Sedej
    Gijsbert ter Horst (Ghostbird)
    Gohan1989
    gugus/gus
    guidoj
    Haoda Wang (h313)
    holorat
    hristoast
    Internecine
    Ivan Beloborodov (myrix)
    Jackerty
    Jacob Essex (Yacoby)
    Jacob Turnbull (Tankinfrank)
    Jake Westrip (16bitint)
    James Carty (MrTopCat)
    James Deciutiis (JamesDeciutiis)
    James Moore (moore.work)
    James Stephens (james-h-stephens)
    Jan-Peter Nilsson (peppe)
    Jan Borsodi (am0s)
    JanuarySnow
    Jason Hooks (jhooks)
    jeaye
    jefetienne
    Jeffrey Haines (Jyby)
    Jengerer
    Jiří Kuneš (kunesj)
    Joe Wilkerson (neuralroberts)
    Joel Graff (graffy)
    John Blomberg (fstp)
    Jordan Ayers
    Jordan Milne
    Josquin Frei
    Josua Grawitter
    Jules Blok (Armada651)
    julianko
    Julien Voisin (jvoisin/ap0)
    Karl-Felix Glatzer (k1ll)
    Kevin Poitra (PuppyKevin)
    Koncord
    Kurnevsky Evgeny (kurnevsky)
    Lars Söderberg (Lazaroth)
    lazydev
    Léo Peltier
    Leon Krieg (lkrieg)
    Leon Saunders (emoose)
    logzero
    lohikaarme
    Lordrea
    Łukasz Gołębiewski (lukago)
    Lukasz Gromanowski (lgro)
    Mads Sandvei (Foal)
    Maksim Eremenko (Max Yari)
    Marc Bouvier (CramitDeFrog)
    Marcin Hulist (Gohan)
    Mark Siewert (mark76)
    Marco Melletti (mellotanica)
    Marco Schulze
    Martin Otto (MAtahualpa)
    Mateusz Kołaczek (PL_kolek)
    Mateusz Malisz (malice)
    Max Henzerling (SaintMercury)
    megaton
    Mehdi Yousfi-Monod (mym)
    Michael Hogan (Xethik)
    Michael Mc Donnell
    Michael Papageorgiou (werdanith)
    Michael Stopa (Stomy)
    Michał Ściubidło (mike-sc)
    Michał Bień (Glorf)
    Michał Moroz (dragonee)
    Miloslav Číž (drummyfish)
    Miroslav Puda (pakanek)
    MiroslavR
    Mitchell Schwitzer (schwitzerm)
    Mitten.O
    naclander
    Narmo
    Nat Meo (Utopium)
    Nathan Jeffords (blunted2night)
    NeveHanter
    Nialsy
    Nick Crawford (nighthawk469)
    Nikolay Kasyanov (corristo)
    Noah Gooder
    nobrakal
    Nolan Poe (nopoe)
    Nurivan Gomez (Nuri-G)
    Oleg Chkan (mrcheko)
    Paul Cercueil (pcercuei)
    Paul McElroy (Greendogo)
    pchan3
    Perry Hugh
    Petr Mikheev (ptmikheev)
    Phillip Andrews (PhillipAnd)
    Pi03k
    Pieter van der Kloet (pvdk)
    pkubik
    PLkolek
    PlutonicOverkill
    Qlonever
    Radu-Marius Popovici (rpopovici)
    Rafael Moura (dhustkoder)
    Randy Davin (Kindi)
    rdimesio
    rexelion
    riothamus
    Rob Cutmore (rcutmore)
    Robert MacGregor (Ragora)
    Rohit Nirmal
    Roman Melnik (Kromgart)
    Roman Proskuryakov (kpp)
    Roman Siromakha (elsid)
    Sandy Carter (bwrsandman)
    Scott Howard (maqifrnswa)
    Sebastian Wick (swick)
    Sergey Fukanchik
    Sergey Shambir (sergey-shambir)
    sergoz
    ShadowRadiance
    Shihan42
    Siimacore
    Simon Meulenbeek (simonmb)
    sir_herrbatka
    smbas
    Sophie Kirschner (pineapplemachine)
    spycrab
    Stefan Galowicz (bogglez)
    Stanislav Bobrov (Jiub)
    Stanislaw Halik (sthalik)
    Star-Demon
    stil-t
    svaante
    Sylvain Thesnieres (Garvek)
    t6
    terrorfisch
    Tess (tescoShoppah)
    thegriglat
    Thomas Luppi (Digmaster)
    Tim Hagberg (hazardMan)
    tlmullis
    trav
    tri4ng1e
    Thoronador
    Tobias Tribble (zackhasacat)
    Tom Lowe (Vulpen)
    Tom Mason (wheybags)
    Torben Leif Carrington (TorbenC)
    unelsson
    uramer
    viadanna
    Vidi_Aquam
    Vincent Heuken
    Vladimir Panteleev (CyberShadow)
    vocollapse
    Wang Ryu (bzzt)
    Will Herrmann (Thunderforge)
    Wolfgang Lieff
    xyzz
    Yohaulticetl
    Yuri Krupenin
    Yury Stepovikov
    zelurker

Documentation
-------------

    Adam Bowen (adamnbowen)
    Alejandro Sanchez (HiPhish)
    Bodillium
    Bret Curtis (psi29a)
    Cramal
    David Walley (Loriel)
    Diego Crespo
    Joakim Berg (lysol90)
    Ryan Tucker (Ravenwing)
    sir_herrbatka
    David Nagy (zuzaman)

Packagers
---------

    Alexander Olofsson (Ananace) - Windows and Flatpak
    Alexey Sokolov (DarthGandalf) - Gentoo Linux
    Bret Curtis (psi29a) - Debian and Ubuntu Linux
    Edmondo Tommasina (edmondo) - Gentoo Linux
    Julian Ospald (hasufell) - Gentoo Linux
    Karl-Felix Glatzer (k1ll) - Linux Binaries
    Kenny Armstrong (artorius) - Fedora Linux
    Nikolay Kasyanov (corristo) - Mac OS X
    Sandy Carter (bwrsandman) - Arch Linux

Public Relations and Translations
---------------------------------

    Artem Kotsynyak (greye) - Russian News Writer
    Dawid Lakomy (Vedyimyn) - Polish News Writer
    ElderTroll - Release Manager
    Jim Clauwaert (Zedd) - Public Outreach
    juanmnzsk8 - Spanish News Writer
    Julien Voisin (jvoisin/ap0) - French News Writer
    Kingpix - Italian News Writer
    Lukasz Gromanowski (lgro) - English News Writer
    Martin Otto (Atahualpa) - Podcaster, Public Outreach, German Translator
    Mickey Lyle (raevol) - Release Manager
    Nekochan - English News Writer
    penguinroad - Indonesian News Writer
    Pithorn - Chinese News Writer
    sir_herrbatka - Polish News Writer
    spyboot - German Translator
    Tom Koenderink (Okulo) - English News Writer

Website
-------

    Lukasz Gromanowski (Lgro) - Website Administrator
    Ryan Sardonic (Wry) - Wiki Editor
    sir_herrbatka - Forum Administrator

Formula Research
----------------

    Hrnchamd
    Epsilon
    fragonard
    Greendogo
    HiPhish
    modred11
    Myckel
    natirips
    Sadler

Artwork
-------

    Necrod - OpenMW Logo
    Mickey Lyle (raevol) - Wordpress Theme
    Tom Koenderink (Okulo), SirHerrbatka, crysthala, Shnatsel, Lamoot - OpenMW Editor Icons

Additional Credits
------------------
In this section we would like to thank people not part of OpenMW for their work.

Thanks to Maxim Nikolaev,
for allowing us to use his excellent Morrowind fan-art on our website and in other places.

Thanks to DokterDume,
for kindly providing us with the Moon and Star logo, used as the application icon and project logo.

Thanks to Kevin Ryan,
for creating the icon used for the Data Files tab of the OpenMW Launcher.

Thanks to DejaVu team,
for their DejaVuLGCSansMono fontface, see DejaVuFontLicense.txt for their license terms.

==> openmw-0.50.0.tar.gz: openmw-openmw-0.50.0/AUTHORS.md <==
Contributors
============

The OpenMW project was started in 2008 by Nicolay Korslund.
In the course of years many people have contributed to the project.

If you feel your name is missing from this list, please add it to `AUTHORS.md`.


Programmers
-----------

    Alexey Dobrokhotov (Capo) - Project leader 2025-present
    Bret Curtis (psi29a) - Project leader 2019-2025
    Marc Zinnschlag (Zini) - Project leader 2010-2018
    Nicolay Korslund - Project leader 2008-2010
    scrawl - Top contributor

    AbduSharif
    Adam Hogan (aurix)
    Aesylwinn
    aegis
    AHSauge
    Aleksandar Jovanov
    Alex Haddad (rainChu)
    Alex McKibben
    alexanderkjall
    Alexander Nadeau (wareya)
    Alexander Olofsson (Ananace)
    Alex Rice
    Alex S (docwest)
    Alexey Yaryshev (skeevert)
    Allofich
    Andreas Stöckel
    Andrei Kortunov (akortunov)
    Andrew Appuhamy (andrew-app)
    Andrzej Głuszak (agluszak)
    AnyOldName3
    Ardekantur
    Armin Preiml
    Artem Kotsynyak (greye)
    Artem Nykolenko (anikm21)
    artemutin
    Arthur Moore (EmperorArthur)
    Assumeru
    athile
    Aussiemon
    Austin Salgat (Salgat)
    Ben Shealy (bentsherman)
    Berulacks
    Bo Svensson
    Britt Mathis (galdor557)
    Carl Maxwell
    cc9cii
    Cédric Mocquillon
    Charles Horn
    Chris Boyce (slothlife)
    Chris Robinson (KittyCat)
    Chris Vigil
    Cody Glassman (Wazabear)
    Coleman Smith (olcoal)
    Cory F. Cohen (cfcohen)
    Cris Mihalache (Mirceam)
    crussell187
    Sam Hellawell (cykoder)
    Dan Vukelich (sanchezman)
    darkf
    Dave Corley (S3ctor)
    David Cernat (davidcernat)
    Declan Millar (declan-millar)
    devnexen
    Dieho
    Dmitry Shkurskiy (endorph)
    Douglas Diniz (Dgdiniz)
    Douglas Mencken (dougmencken)
    dreamer-dead
    David Teviotdale (dteviot)
    Diggory Hardy
    Dmitry Marakasov (AMDmi3)
    Duncan Frost (duncans_pumpkin)
    Edmondo Tommasina (edmondo)
    Eduard Cot (trombonecot)
    Eli2
    Emanuel Guével (potatoesmaster)
    Epoch
    Eris Caffee (eris)
    eroen
    escondida
    Evgeniy Mineev (sandstranger)
    Federico Guerra (FedeWar)
    Fil Krynicki (filkry)
    Finbar Crago (finbar-crago)
    Florent Teppe (Tetramir)
    Florian Weber (Florianjw)
    Frédéric Chardon (fr3dz10)
    Gaëtan Dezeiraud (Brouilles)
    Gašper Sedej
    Gijsbert ter Horst (Ghostbird)
    Gohan1989
    gugus/gus
    guidoj
    Hailey Tribble (daisyhasacat)
    Haoda Wang (h313)
    holorat
    hristoast
    Internecine
    Ivan Beloborodov (myrix)
    Jackerty
    Jacob Essex (Yacoby)
    Jacob Turnbull (Tankinfrank)
    Jake Westrip (16bitint)
    James Carty (MrTopCat)
    James Deciutiis (JamesDeciutiis)
    James Moore (moore.work)
    James Stephens (james-h-stephens)
    Jan-Peter Nilsson (peppe)
    Jan Borsodi (am0s)
    JanuarySnow
    Jason Hooks (jhooks)
    jeaye
    jefetienne
    Jeffrey Haines (Jyby)
    Jengerer
    Jiří Kuneš (kunesj)
    Joe Wilkerson (neuralroberts)
    Joel Graff (graffy)
    John Blomberg (fstp)
    Jordan Ayers
    Jordan Milne
    Josquin Frei
    Josua Grawitter
    Jules Blok (Armada651)
    julianko
    Julien Voisin (jvoisin/ap0)
    Karl-Felix Glatzer (k1ll)
    Kevin Poitra (PuppyKevin)
    Koncord
    Kurnevsky Evgeny (kurnevsky)
    Lars Söderberg (Lazaroth)
    lazydev
    Léo Peltier
    Leon Krieg (lkrieg)
    Leon Saunders (emoose)
    logzero
    lohikaarme
    Lordrea
    Łukasz Gołębiewski (lukago)
    Lukasz Gromanowski (lgro)
    Mads Sandvei (Foal)
    Maksim Eremenko (Max Yari)
    Marc Bouvier (CramitDeFrog)
    Marcin Hulist (Gohan)
    Mark Siewert (mark76)
    Marco Melletti (mellotanica)
    Marco Schulze
    Martin Otto (MAtahualpa)
    Mateusz Kołaczek (PL_kolek)
    Mateusz Malisz (malice)
    Max Henzerling (SaintMercury)
    megaton
    Mehdi Yousfi-Monod (mym)
    Michael Hogan (Xethik)
    Michael Mc Donnell
    Michael Papageorgiou (werdanith)
    Michael Stopa (Stomy)
    Michał Ściubidło (mike-sc)
    Michał Bień (Glorf)
    Michał Moroz (dragonee)
    Miloslav Číž (drummyfish)
    Miroslav Puda (pakanek)
    MiroslavR
    Mitchell Schwitzer (schwitzerm)
    Mitten.O
    naclander
    Narmo
    Nat Meo (Utopium)
    Nathan Jeffords (blunted2night)
    NeveHanter
    Nialsy
    Nick Crawford (nighthawk469)
    Nikolay Kasyanov (corristo)
    Noah Gooder
    nobrakal
    Nolan Poe (nopoe)
    Nurivan Gomez (Nuri-G)
    Oleg Chkan (mrcheko)
    Paul Cercueil (pcercuei)
    Paul McElroy (Greendogo)
    pchan3
    Perry Hugh
    Petr Mikheev (ptmikheev)
    Phillip Andrews (PhillipAnd)
    Pi03k
    Pieter van der Kloet (pvdk)
    pkubik
    PLkolek
    PlutonicOverkill
    Qlonever
    Radu-Marius Popovici (rpopovici)
    Rafael Moura (dhustkoder)
    Randy Davin (Kuyondo)
    rdimesio
    rexelion
    riothamus
    Rob Cutmore (rcutmore)
    Robert MacGregor (Ragora)
    Rohit Nirmal
    Roman Melnik (Kromgart)
    Roman Proskuryakov (kpp)
    Roman Siromakha (elsid)
    Sandy Carter (bwrsandman)
    Scott Howard (maqifrnswa)
    Sebastian Wick (swick)
    Sergey Fukanchik
    Sergey Shambir (sergey-shambir)
    sergoz
    ShadowRadiance
    Shihan42
    Siimacore
    Simon Meulenbeek (simonmb)
    sir_herrbatka
    smbas
    Sophie Kirschner (pineapplemachine)
    spycrab
    Stefan Galowicz (bogglez)
    Stanislav Bobrov (Jiub)
    Stanislaw Halik (sthalik)
    Star-Demon
    stil-t
    svaante
    Sylvain Thesnieres (Garvek)
    t6
    terrorfisch
    Tess (tescoShoppah)
    thegriglat
    Thomas Luppi (Digmaster)
    Tim Hagberg (hazardMan)
    tlmullis
    trav
    tri4ng1e
    Thoronador
    Tom Lowe (Vulpen)
    Tom Mason (wheybags)
    Torben Leif Carrington (TorbenC)
    unelsson
    uramer
    viadanna
    Vidi_Aquam
    Vincent Heuken
    Vladimir Panteleev (CyberShadow)
    vocollapse
    Wang Ryu (bzzt)
    Will Herrmann (Thunderforge)
    Wolfgang Lieff
    xyzz
    Yohaulticetl
    Yuri Krupenin
    Yury Stepovikov
    zelurker

Documentation
-------------

    Adam Bowen (adamnbowen)
    Alejandro Sanchez (HiPhish)
    Bodillium
    Bret Curtis (psi29a)
    Cramal
    David Walley (Loriel)
    Diego Crespo
    Joakim Berg (lysol90)
    Ryan Tucker (Ravenwing)
    sir_herrbatka
    David Nagy (zuzaman)

Packagers
---------

    Alexander Olofsson (Ananace) - Windows and Flatpak
    Alexey Sokolov (DarthGandalf) - Gentoo Linux
    Bret Curtis (psi29a) - Debian and Ubuntu Linux
    Edmondo Tommasina (edmondo) - Gentoo Linux
    Julian Ospald (hasufell) - Gentoo Linux
    Karl-Felix Glatzer (k1ll) - Linux Binaries
    Kenny Armstrong (artorius) - Fedora Linux
    Nikolay Kasyanov (corristo) - Mac OS X
    Sandy Carter (bwrsandman) - Arch Linux

Public Relations and Translations
---------------------------------

    Artem Kotsynyak (greye) - Russian News Writer
    Dawid Lakomy (Vedyimyn) - Polish News Writer
    ElderTroll - Release Manager
    Igor Wiśniewski (Igilq) - Polish Translation
    Jim Clauwaert (Zedd) - Public Outreach
    juanmnzsk8 - Spanish News Writer
    Julien Voisin (jvoisin/ap0) - French News Writer
    Kingpix - Italian News Writer
    Lukasz Gromanowski (lgro) - English News Writer
    Martin Otto (Atahualpa) - Podcaster, Public Outreach, German Translator
    Mickey Lyle (raevol) - Release Manager
    Nekochan - English News Writer
    penguinroad - Indonesian News Writer
    Pithorn - Chinese News Writer
    sir_herrbatka - Polish News Writer
    spyboot - German Translator
    Tom Koenderink (Okulo) - English News Writer

Website
-------

    Lukasz Gromanowski (Lgro) - Website Administrator
    Ryan Sardonic (Wry) - Wiki Editor
    sir_herrbatka - Forum Administrator

Formula Research
----------------

    Hrnchamd
    Epsilon
    fragonard
    Greendogo
    HiPhish
    modred11
    Myckel
    natirips
    Sadler

Artwork
-------

    Necrod - OpenMW Logo
    Mickey Lyle (raevol) - Wordpress Theme
    Tom Koenderink (Okulo), SirHerrbatka, crysthala, Shnatsel, Lamoot - OpenMW Editor Icons

Additional Credits
------------------
In this section we would like to thank people not part of OpenMW for their work.

Thanks to Maxim Nikolaev,
for allowing us to use his excellent Morrowind fan-art on our website and in other places.

Thanks to DokterDume,
for kindly providing us with the Moon and Star logo, used as the application icon and project logo.

Thanks to Kevin Ryan,
for creating the icon used for the Data Files tab of the OpenMW Launcher.

Thanks to DejaVu team,
for their DejaVuLGCSansMono fontface, see DejaVuFontLicense.txt for their license terms.
